@@ -8,7 +8,7 @@ from jkUnicode.tools.jsonhelpers import dict_from_file
 from typing import Any, Dict, List, Optional, Set
 
 
-# These unicode points are ignored when scanning for orthography support
+# These codepoints are ignored when scanning for orthography support
 IGNORED_UNICODES = [
     # Minute and second appear in lots of language definitions in CLDR, but are
     # not in very many fonts.
@@ -26,7 +26,7 @@ class Orthography:
     :param info_obj: The parent info object.
     :type info_obj: :py:class:`jkUnicode.orthography.OrthographyInfo`
 
-    :param code: The orthography code.
+    :param code: The ISO-639-1 code for the orthography.
     :type code: str
 
     :param script: The script code of the orthography.
@@ -50,7 +50,7 @@ class Orthography:
     ) -> None:
         self._info = info_obj
         if self._info is None:
-            self._ui = UniInfo(0)
+            self._ui = UniInfo()
         else:
             self._ui = self._info.ui
         self.code = code
@@ -68,24 +68,20 @@ class Orthography:
 
     def from_dict(self, info_dict: Dict[str, Any]) -> None:
         """
-                Read information for the current orthography from a dictionary. This
-                method is called during initialization of the object and fills in a
-                number of instance attributes:
+        Read information for the current orthography from a dictionary. This
+        method is called during initialization of the object and fills in a
+        number of instance attributes:
 
-        name
-           The orthography name.
+        `name`: The orthography name.
 
-        unicodes_base
-           The set of base characters for the orthography.
+        `unicodes_base`: The set of base characters for the orthography.
 
-        unicodes_optional
-           The set of optional characters for the orthography.
+        `unicodes_optional`: The set of optional characters for the orthography.
 
-        unicodes_punctuation
-           The set of punctuation characters for the orthography.
+        `unicodes_punctuation`: The set of punctuation characters for the
+        orthography.
 
-        unicodes_any
-           The previous three sets combined.
+        `unicodes_any`: The previous three sets combined.
         """
         self.scan_ok = False
 
@@ -140,10 +136,19 @@ class Orthography:
 
     @property
     def ui(self) -> UniInfo:
+        """
+        The :py:class:`jkUnicode.UniInfo` object that is queried for Unicode
+        information.
+        """
         return self._ui
     
     @property
     def ignored_unicodes(self) -> Set[int]:
+        """
+        The set of ignored codepoints. If a parent
+        :py:class:`jkUnicode.orthography.OrthographyInfo` object exists, it is
+        taken from there.
+        """
         if self.info is None:
             return set()
         return self.info.ignored_unicodes
@@ -156,22 +161,22 @@ class Orthography:
         Return a list with its Unicode case mapping toggled. If a codepoint has
         no lowercase or uppercase mapping, it is dropped from the list.
 
-        :param codepoint_list: The list of integer codepoints.
+        :param codepoint_list: The list of codepoints.
         :type codepoint_list: list
         """
-        result = []
+        result = set()
         for c in codepoint_list:
             self.ui.unicode = c
             if self.ui.lc_mapping:
-                result.append(self.ui.lc_mapping)
+                result.add(self.ui.lc_mapping)
             elif self.ui.uc_mapping:
-                result.append(self.ui.uc_mapping)
-        return list(set(result))
+                result.add(self.ui.uc_mapping)
+        return sorted(list(result))
 
     def fill_from_default_orthography(self) -> None:
         """
-        Sometimes the base unicodes are empty for a variant of an orthography.
-        Try to fill them in from the default variant.
+        Sometimes the base codepoints are empty for a variant of an
+        orthography. Try to fill them in from the default variant.
 
         Call this only after the whole list of orthographies is present, or it
         will fail, because the default orthography may not be present until the
@@ -257,7 +262,7 @@ class Orthography:
 
     def almost_supported_full(self, max_missing: int = 5) -> bool:
         """
-        Is the orthography supported with a maximum of max_missing characters
+        Is the orthography supported with a maximum of `max_missing` characters
         (base, optional and punctuation characters) for the current parent
         cmap?
         """
@@ -267,7 +272,7 @@ class Orthography:
 
     def almost_supported_basic(self, max_missing: int = 5) -> bool:
         """
-        Is the orthography supported with a maximum of max_missing base
+        Is the orthography supported with a maximum of `max_missing` base
         characters for the current parent cmap?
         """
         if 0 < self.num_missing_base <= max_missing:
@@ -276,8 +281,8 @@ class Orthography:
 
     def almost_supported_punctuation(self, max_missing: int = 5) -> bool:
         """
-        Is the orthography supported with a maximum of max_missing punctuation
-        characters for the current parent cmap?
+        Is the orthography supported with a maximum of `max_missing`
+        punctuation characters for the current parent cmap?
         """
         if (
             self.num_missing_base == 0
@@ -288,7 +293,7 @@ class Orthography:
 
     def uses_unicode_base(self, u: int) -> bool:
         """
-        Is the unicode used by this orthography in the base set? This is
+        Is the codepoint used by this orthography in the base set? This is
         relatively slow. Use
         :py:func:`jkUnicode.orthography.OrthographyInfo.build_reverse_cmap` if
         you need to access this information more often.
@@ -302,8 +307,8 @@ class Orthography:
 
     def uses_unicode_any(self, u: int) -> bool:
         """
-        Is the unicode used by this orthography in any set? This is relatively
-        slow. Use
+        Is the codepoint used by this orthography in any set? This is
+        relatively slow. Use
         :py:func:`jkUnicode.orthography.OrthographyInfo.build_reverse_cmap` if
         you need to access this information more often.
 
@@ -319,28 +324,23 @@ class Orthography:
         Scan the orthography against the current parent cmap. This fills in a
         number of instance attributes:
 
-        missing_base
-           A set of unicode values that are missing from the basic characters
-           of the orthography.
+        `missing_base`: A set of unicode values that are missing from the basic
+        characters of the orthography.
 
-        missing_optional
-           A set of unicode values that are missing from the optional
-           characters of the orthography.
+        `missing_optional`: A set of unicode values that are missing from the
+        optional characters of the orthography.
 
-        missing_punctuation
-           A set of unicode values that are missing from the punctuation
-           characters of the orthography.
+        `missing_punctuation`: A set of unicode values that are missing from
+        the punctuation characters of the orthography.
 
-        missing_all
-           A set of all the previous combined.
+        `missing_all`: A set of all the previous combined.
 
-        num_missing_base, num_missing_optional, num_missing_punctuation,
-        num_missing_all
-           The number of missing characters for the previous attributes
+        `num_missing_base, num_missing_optional, num_missing_punctuation,
+        num_missing_all`: The number of missing characters for the previous
+        attributes
 
-        base_pc, optional_pc, punctuation_pc
-           The percentage values of support for the categories basic, optional,
-           and punctuation characters.
+        `base_pc, optional_pc, punctuation_pc`: The percentage values of
+        support for the categories basic, optional, and punctuation characters.
 
         The names of these attributes can be used in
         :py:class:`jkUnicode.orthography.OrthographyInfo.print_report`.
@@ -404,9 +404,10 @@ class Orthography:
         self.scan_ok = False
 
     @property
-    def info(self) -> Optional[Any]:
+    def info(self) -> Optional["OrthographyInfo"]:
         """
-        The parent OrthographyInfo object (read-only).
+        The parent :py:class:`jkUnicode.orthography.OrthographyInfo` object
+        (read-only).
         """
         # self._info is a weakref, call it to return its object
         # return self._info()
@@ -414,6 +415,9 @@ class Orthography:
 
     @property
     def identifier(self) -> str:
+        """
+        Return an identifier for language code/script/territory (read-only).
+        """
         _id = self.code
         if self.script != "DFLT":
             _id += "_%s" % self.script
@@ -424,7 +428,7 @@ class Orthography:
     @property
     def name(self) -> str:
         """
-        The name of the orthography (read-only).
+        The name of the orthography.
         """
         return self._name
 
@@ -469,7 +473,7 @@ class OrthographyInfo:
     def __init__(self, ui: Optional[UniInfo] = None) -> None:
         # We need a UniInfo object
         if ui is None:
-            self.ui = UniInfo(0)
+            self.ui = UniInfo()
         else:
             self.ui = ui
 
@@ -725,7 +729,7 @@ class OrthographyInfo:
                 self.ui.unicode = u
                 print(
                     "    0x%04X\t%s\t%s" % (
-                        u, self.ui.glyphname, self.ui.name.title()
+                        u, self.ui.glyphname, self.ui.nice_name
                     )
                 )
 
